@@ -5,12 +5,13 @@
 #' @param D Data frame whith the simulations.
 #' @param family Name of the family of parameters to plot, as given by a character vector or a regular expression. A family of parameters is considered to be any group of parameters with the same name but different numerical value between square brackets (as beta[1], beta[2], etc). 
 #' @param absolute_scale Logical. When TRUE (the default), the scale of the colour diverges between perfect inverse correlation (-1) to perfect correlation (1), whereas when FALSE, the scale is relative to the minimum and maximum cross-correlations observed.
+#' @param greek Logical value indicating whether parameter labels have to be parsed to get Greek letters. Defaults to false.
 #' @return a \code{ggplot} object.
 #' @export
 #' @examples
 #' data(linear)
 #' ggs_crosscorrelation(ggs(s))
-ggs_crosscorrelation <- function(D, family=NA, absolute_scale=TRUE) {
+ggs_crosscorrelation <- function(D, family=NA, absolute_scale=TRUE, greek=FALSE) {
   # Manage subsetting a family of parameters
   if (!is.na(family)) {
     D <- get_family(D, family=family)
@@ -36,5 +37,9 @@ ggs_crosscorrelation <- function(D, family=NA, absolute_scale=TRUE) {
     } else {
       f <- f + scale_fill_gradient2() 
     }
+  if (greek) {
+    f <- f + scale_x_discrete(labels = parse(text = as.character(bc.cc$Var1)))
+    f <- f + scale_y_discrete(labels = parse(text = as.character(bc.cc$Var1))) # caution with this
+  }
   return(f)
 }
