@@ -5,12 +5,13 @@
 #' @param D Data frame whith the simulations.
 #' @param family Name of the family of parameters to plot, as given by a character vector or a regular expression. A family of parameters is considered to be any group of parameters with the same name but different numerical value between square brackets (as beta[1], beta[2], etc). 
 #' @param rug Logical indicating whether a rug must be added to the plot. It is FALSE by default, since in large chains it may use lot of resources and it is not central to the plot.
+#' @param greek Logical value indicating whether parameter labels have to be parsed to get Greek letters. Defaults to false.
 #' @return A \code{ggplot} object.
 #' @export
 #' @examples
 #' data(linear)
 #' ggs_density(ggs(s))
-ggs_density <- function(D, family=NA, rug=FALSE) {
+ggs_density <- function(D, family=NA, rug=FALSE, greek=FALSE) {
   # Manage subsetting a family of parameters
   if (!is.na(family)) {
     D <- get_family(D, family=family)
@@ -22,8 +23,12 @@ ggs_density <- function(D, family=NA, rug=FALSE) {
     f <- ggplot(D, aes(x=value, colour=as.factor(Chain), fill=as.factor(Chain)))
   }
   f <- f + geom_density(alpha=0.3) + 
-      facet_wrap(~ Parameter, ncol=1, scales="free") +
       scale_fill_discrete(name="Chain") + scale_colour_discrete(name="Chain")
+  if (!greek) {
+      f <- f + facet_wrap(~ Parameter, ncol=1, scales="free")
+  } else {
+      f <- f + facet_wrap(~ Parameter, ncol=1, scales="free", labeller = label_parsed)
+  }
   if (rug) f <- f + geom_rug(alpha=0.1)
   return(f)
 }
